@@ -739,6 +739,14 @@ class NagPack(metaclass=jsii.JSIIAbstractClass, jsii_type="monocdk-nag.NagPack")
         '''
         return typing.cast(builtins.str, jsii.invoke(self, "ignoreRule", [ignores, rule_id, finding_id]))
 
+    @jsii.member(jsii_name="initializeStackReport")
+    def _initialize_stack_report(self, params: IApplyRule) -> None:
+        '''Initialize the report for the rule pack's compliance report for the resource's Stack if it doesn't exist.
+
+        :param params: -
+        '''
+        return typing.cast(None, jsii.invoke(self, "initializeStackReport", [params]))
+
     @jsii.member(jsii_name="visit") # type: ignore[misc]
     @abc.abstractmethod
     def visit(self, node: monocdk.IConstruct) -> None:
@@ -756,7 +764,7 @@ class NagPack(metaclass=jsii.JSIIAbstractClass, jsii_type="monocdk-nag.NagPack")
         compliance: typing.Union["NagRuleCompliance", builtins.str],
         explanation: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''Write a line to the rule packs compliance report for the resource's Stack.
+        '''Write a line to the rule pack's compliance report for the resource's Stack.
 
         :param params: The.
         :param rule_id: The id of the rule.
